%ifarch %{arm32} %{ix86}
%bcond_with mappreview
%else
%bcond_without mappreview
%endif

Summary:        GPSBabel converts GPS data from one format to another
Name:           gpsbabel
Version:        1.9.0
Release:        %mkrel 3
License:        GPLv2+
Group:          Geography
URL:            https://www.gpsbabel.org
# Source:               https://prdownloads.sourceforge.net/%%{name}/%%{name}-%%{version}.tar.gz
# Needs to be downloaded from the https://www.gpsbabel.org/ URL.
Source0:        gpsbabel-%{version}.tar.gz
Source2:        %{name}.png
# Fedora patches:
# No automatic phone home by default (RHBZ 668865)
Patch2:         0002-No-solicitation.patch
BuildRequires:  cmake
BuildRequires:  pkgconfig(expat)
BuildRequires:  pkgconfig(libusb)
BuildRequires:  pkgconfig(minizip)
BuildRequires:  pkgconfig(zlib)
BuildRequires:  pkgconfig(shapelib)
BuildRequires:  desktop-file-utils
BuildRequires:  cmake(Qt6Core5Compat)
BuildRequires:  cmake(Qt6Core)
BuildRequires:  cmake(Qt6Gui)
BuildRequires:  cmake(Qt6Network)
BuildRequires:  cmake(Qt6SerialPort)
BuildRequires:  cmake(Qt6Widgets)
BuildRequires:  cmake(Qt6Xml)
%if %{with mappreview}
BuildRequires:  cmake(Qt6WebEngineWidgets)
BuildRequires:  cmake(Qt6WebChannel)
%endif
BuildRequires:  qt6-qttools
BuildRequires:  qt6-qttranslations

# pull-in qt6 standard translations.
# Otherwise items such as "Close", "Open" won't be translated
Requires:       qt6-qttranslations

%description
GPSBabel converts waypoints, tracks, and routes from one format to another,
whether that format is a common mapping format like Delorme, Streets and
Trips, or even a serial upload or download to a GPS unit such as those from
Garmin and Magellan. By flatting the Tower of Babel that the authors of
various programs for manipulating GPS data have imposed upon us, it returns
to us the ability to freely move our own waypoint data between the programs
and hardware we choose to use.

%if %{with mappreview}
%package gui
Summary:        Qt GUI interface for GPSBabel
Group:          Geography
License:        GPLv2+
Requires:       %{name} = %{version}-%{release}

%description gui
Qt GUI interface for GPSBabel.
%endif

%prep
%autosetup -p1

%build
%cmake \
        -DGPSBABEL_WITH_LIBUSB=pkgconfig \
        -DGPSBABEL_WITH_ZLIB=pkgconfig \
        -DGPSBABEL_WITH_SHAPELIB=pkgconfig \
        %{!?with_mappreview:-DGPSBABEL_MAPPREVIEW:BOOL=OFF} \
        %nil

%cmake_build

%install
%cmake_install

install -m 0755 -d %{buildroot}%{_bindir}/
install -m 0755 -p %{_vpath_builddir}/gpsbabel %{buildroot}%{_bindir}/

%if %{with mappreview}
install -m 0755 -d %{buildroot}%{_bindir}/
install -m 0755 -p %{_vpath_builddir}/gui/GPSBabelFE/gpsbabelfe %{buildroot}%{_bindir}/

install -m 0755 -d %{buildroot}%{_datadir}/gpsbabel
install -m 0644 -p gui/gmapbase.html %{buildroot}%{_datadir}/gpsbabel

desktop-file-install \
        --dir %{buildroot}/%{_datadir}/applications \
        gui/gpsbabel.desktop

install -m 0755 -d            %{buildroot}%{_datadir}/icons/hicolor/256x256/apps/
install -m 0644 -p %{SOURCE2} %{buildroot}%{_datadir}/icons/hicolor/256x256/apps/
%endif

%files
%doc README* AUTHORS
%license COPYING
%{_bindir}/%{name}

%if %{with mappreview}
%files gui
%doc gui/{AUTHORS,README*,TODO}
%license gui/COPYING*
%{_bindir}/gpsbabelfe
%{_datadir}/gpsbabel/
%{_datadir}/applications/*
%{_iconsdir}/hicolor/*/apps/*
%endif


%changelog
* Tue Nov 12 2024 daviddavid <daviddavid> 1.9.0-3.mga10
+ Revision: 2114365
- switch to Qt6
- disable map preview (gui support) on 32bit arches as of lack of Qt6Webengine

* Thu Oct 10 2024 daviddavid <daviddavid> 1.9.0-2.mga10
+ Revision: 2104529
- rebuild for new shapelib 1.6.1

* Fri Oct 27 2023 daviddavid <daviddavid> 1.9.0-1.mga10
+ Revision: 2002101
- new version: 1.9.0
- do not install *.qm (tstevens4)
- add R/BR: qttranslations5

* Sat Dec 24 2022 daviddavid <daviddavid> 1.8.0-1.mga9
+ Revision: 1926396
- new version: 1.8.0
- switch to cmake buld system
- use upstream desktop file
- remove unused patches

* Tue Apr 05 2022 umeabot <umeabot> 1.7.0-3.mga9
+ Revision: 1844973
- Mageia 9 Mass Rebuild

* Wed Dec 16 2020 umeabot <umeabot> 1.7.0-2.mga8
+ Revision: 1658503
- Rebuild for new Qt5

* Tue Aug 18 2020 shlomif <shlomif> 1.7.0-1.mga8
+ Revision: 1614795
- New version 1.7.0
+ umeabot <umeabot>
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Wed Nov 20 2019 daviddavid <daviddavid> 1.6.0-1.mga8
+ Revision: 1461769
- new version: 1.6.0
- sync all patches with fedora's one
- fix translations dir path

* Sat Mar 30 2019 umeabot <umeabot> 1.5.4-4.mga7
+ Revision: 1381822
- Qt5 Rebuild

* Sun Sep 23 2018 umeabot <umeabot> 1.5.4-3.mga7
+ Revision: 1298050
- Mageia 7 Mass Rebuild

* Tue Oct 10 2017 daviddavid <daviddavid> 1.5.4-2.mga7
+ Revision: 1170715
- patch7: upstream patch to fix build with gcc7
- rebuild for new shapelib 1.4.1

* Mon Jul 17 2017 shlomif <shlomif> 1.5.4-1.mga7
+ Revision: 1124555
- add missing BR
- New version 1.5.4 - convert to qt5

* Sun Apr 17 2016 shlomif <shlomif> 1.5.3-1.mga6
+ Revision: 1003263
- New version 1.5.3. Regenerated some patches.

* Mon Feb 15 2016 umeabot <umeabot> 1.5.0-5.mga6
+ Revision: 960519
- Mageia 6 Mass Rebuild

* Sun Oct 18 2015 daviddavid <daviddavid> 1.5.0-4.mga6
+ Revision: 892582
- remove empty lang files to fix build with latest rpm

* Wed Oct 15 2014 umeabot <umeabot> 1.5.0-3.mga5
+ Revision: 750721
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.5.0-2.mga5
+ Revision: 679918
- Mageia 5 Mass Rebuild

* Sun Jul 06 2014 tv <tv> 1.5.0-1.mga5
+ Revision: 644129
- fix linking
- new release
- resync patches with FC
- switch to pkgconfig() style BRs

* Fri Oct 18 2013 umeabot <umeabot> 1.4.4-3.mga4
+ Revision: 505218
- Mageia 4 Mass Rebuild

* Sat Jan 12 2013 umeabot <umeabot> 1.4.4-2.mga3
+ Revision: 352540
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Oct 21 2012 fwang <fwang> 1.4.4-1.mga3
+ Revision: 308954
- update rpm group
- update file list
- more system shaplib patch
- br shapelib
- new version 1.4.4
- sycn with fedora patches

* Sun Dec 18 2011 fwang <fwang> 1.4.2-4.mga2
+ Revision: 183652
- br dekstop-file-utils
- br qtwebkit
- br qtwebkit

* Sun Apr 10 2011 dmorgan <dmorgan> 1.4.2-2.mga1
+ Revision: 82998
- Fix groups (#682)

* Fri Apr 01 2011 tv <tv> 1.4.2-1.mga1
+ Revision: 79586
- new version
- drop patch 1 (merged upstream)
- add GUI sub package

* Fri Apr 01 2011 tv <tv> 1.3.6-3.mga1
+ Revision: 79553
- imported package gpsbabel


* Fri Dec 10 2010 Oden Eriksson <oeriksson@mandriva.com> 1.3.6-3mdv2011.0
+ Revision: 619250
- the mass rebuild of 2010.0 packages

* Fri Sep 11 2009 Thierry Vignaud <tv@mandriva.org> 1.3.6-2mdv2010.0
+ Revision: 437808
- rebuild

* Thu Jan 08 2009 Emmanuel Andry <eandry@mandriva.org> 1.3.6-1mdv2009.1
+ Revision: 327269
- New version 1.3.6
- use configure2_5x
- reimport broken P0 from Fedora
- diff P1 to fix str fmt

* Thu Jul 24 2008 Thierry Vignaud <tv@mandriva.org> 1.3.4-3mdv2009.0
+ Revision: 246546
- rebuild

* Tue Feb 12 2008 Thierry Vignaud <tv@mandriva.org> 1.3.4-1mdv2008.1
+ Revision: 165954
- fix spacing at top of description
- kill re-definition of %%buildroot on Pixel's request

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

* Thu Sep 06 2007 Emmanuel Andry <eandry@mandriva.org> 1.3.4-1mdv2008.0
+ Revision: 81316
- New version

  + Nicolas Vigier <nvigier@mandriva.com>
    - Import gpsbabel



* Sat Jun 03 2006 Stew Benedict <sbenedict@mandriva.com> 1.2.7-1mdv2007.0
- 1.2.7

* Mon May 02 2005 Stew Benedict <sbenedict@mandriva.com> 1.2.5-1mdk
- New release 1.2.5

* Mon May 02 2005 Stew Benedict <sbenedict@mandriva.com> 1.2.3-2mdk
- Rebuild

* Tue Sep 21 2004 Stew Benedict <sbenedict@mandrakesoft.com> 1.2.3-1mdk
- First mandrakelinux release (suggestion from Lars Luthman)
